==> react-form-mobx-0.1.0.tgz: package/es/FormStore/ObjectStore.js <==
var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

import { observable, computed, action } from 'mobx';
import PrimitiveStore from './PrimitiveStore';
import { isFunction } from '../utils';

var ObjectStore = (_class = function (_PrimitiveStore) {
	_inherits(ObjectStore, _PrimitiveStore);

	_createClass(ObjectStore, [{
		key: 'isValid',
		get: function get() {
			if (this.errorMessage) return false;

			var isValid = true;
			this.eachChildren(function (child) {
				if (!isValid || !child.isValid) isValid = false;
			});
			return isValid;
		}
	}]);

	function ObjectStore(pristineValue, options) {
		_classCallCheck(this, ObjectStore);

		var _this = _possibleConstructorReturn(this, (ObjectStore.__proto__ || Object.getPrototypeOf(ObjectStore)).call(this, pristineValue, options));

		_this.change = function (store) {
			if (!isFunction(_this.bus.change)) return;
			var ev = {};
			var defineProperty = function defineProperty(prop, get) {
				Object.defineProperty(ev, prop, {
					enumerable: true,
					configurable: true,
					get: get
				});
			};
			defineProperty('value', function () {
				return _this.value;
			});
			defineProperty('key', function () {
				return store.key;
			});
			_this.bus.change(ev);
			process.nextTick(function () {
				delete ev.value;
				delete ev.key;
			});
		};

		_this.children = observable.map();
		_this.bus.change = options.onChange;
		return _this;
	}

	_createClass(ObjectStore, [{
		key: 'getDefaultStoreValue',
		value: function getDefaultStoreValue() {
			return {};
		}
	}, {
		key: 'applyGetValue',
		value: function applyGetValue() {
			var res = this.getDefaultStoreValue();
			this.eachChildren(function (child, key) {
				res[key] = child.value;
			});
			return res;
		}
	}, {
		key: 'applySetValue',
		value: function applySetValue() {
			var _this2 = this;

			// TODO: should handle deleted and added keys
			this.eachChildren(function (child, key) {
				child.value = _this2.value[key];
			});
		}
	}, {
		key: 'applySetPristineValue',
		value: function applySetPristineValue() {
			var _this3 = this;

			this.isChecked = false;
			this.eachChildren(function (child, key) {
				var val = _this3.sourceValue[key];
				child.pristineValue = val;
			});
		}
	}, {
		key: 'getFormData',
		value: function getFormData() {
			var res = this.getDefaultStoreValue();
			this.eachChildren(function (child, key) {
				var val = child.getFormData();
				if (!child.shouldIgnore(val)) res[key] = val;
			});
			var value = this.getOutputValue(res);
			return this.shouldIgnore(value) ? undefined : value;
		}
	}, {
		key: 'eachChildren',
		value: function eachChildren(iterator) {
			var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
			var _options$checked = options.checked,
			    checked = _options$checked === undefined ? true : _options$checked;
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = this.children[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					var _step$value = _slicedToArray(_step.value, 2),
					    key = _step$value[0],
					    item = _step$value[1];

					if (!checked || item.isChecked) {
						iterator(item, key, this.children);
					}
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}
		}
	}, {
		key: 'shouldCheck',
		value: function shouldCheck(key, value) {
			var val = this.sourceValue[key];
			var checked = val === value;
			if (checked) return checked;
			if (value === true) return val === 'true';
			return false;
		}
	}, {
		key: 'hasKey',
		value: function hasKey(key) {
			return this.sourceValue.hasOwnProperty(key);
		}
	}, {
		key: 'getChildren',
		value: function getChildren(key) {
			var children = this.children;

			if (children.has(key)) return children.get(key);
		}
	}, {
		key: 'setChildren',
		value: function setChildren(key, store) {
			this.children.set(key, store);
			return true;
		}
	}, {
		key: 'touch',
		value: function touch(isTouched) {
			this.eachChildren(function (child) {
				return child.touch(isTouched);
			});
		}
	}, {
		key: 'attach',
		value: function attach(key, options) {
			var sourceValue = this.sourceValue,
			    form = this.form;

			var val = sourceValue[key];
			return form.createChildren(this, key, val, options);
		}
	}, {
		key: 'detach',
		value: function detach(key) {
			this.children.delete(key);
		}
	}]);

	return ObjectStore;
}(PrimitiveStore), (_applyDecoratedDescriptor(_class.prototype, 'isValid', [computed], Object.getOwnPropertyDescriptor(_class.prototype, 'isValid'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'applySetValue', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'applySetValue'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'applySetPristineValue', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'applySetPristineValue'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'touch', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'touch'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'attach', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'attach'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'detach', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'detach'), _class.prototype)), _class);
export { ObjectStore as default };

==> react-form-mobx-0.6.0.tgz: package/es/FormStore/ObjectStore.js <==
var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _desc, _value, _class;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	var desc = {};
	Object['ke' + 'ys'](descriptor).forEach(function (key) {
		desc[key] = descriptor[key];
	});
	desc.enumerable = !!desc.enumerable;
	desc.configurable = !!desc.configurable;

	if ('value' in desc || desc.initializer) {
		desc.writable = true;
	}

	desc = decorators.slice().reverse().reduce(function (desc, decorator) {
		return decorator(target, property, desc) || desc;
	}, desc);

	if (context && desc.initializer !== void 0) {
		desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
		desc.initializer = undefined;
	}

	if (desc.initializer === void 0) {
		Object['define' + 'Property'](target, property, desc);
		desc = null;
	}

	return desc;
}

import { observable, action } from 'mobx';
import PrimitiveStore from './PrimitiveStore';
import { isFunction } from '../utils';

var ObjectStore = (_class = function (_PrimitiveStore) {
	_inherits(ObjectStore, _PrimitiveStore);

	function ObjectStore(pristineValue, options) {
		_classCallCheck(this, ObjectStore);

		var _this = _possibleConstructorReturn(this, (ObjectStore.__proto__ || Object.getPrototypeOf(ObjectStore)).call(this, pristineValue, options));

		_this.change = function (store) {
			if (!isFunction(_this.bus.change)) return;
			var ev = {};
			var defineProperty = function defineProperty(prop, get) {
				Object.defineProperty(ev, prop, {
					enumerable: true,
					configurable: true,
					get: get
				});
			};
			defineProperty('value', function () {
				return _this.value;
			});
			defineProperty('key', function () {
				return store.key;
			});
			_this.bus.change(ev);
			process.nextTick(function () {
				delete ev.value;
				delete ev.key;
			});
		};

		_this.children = observable.map();
		_this.bus.change = options.onChange;
		return _this;
	}

	_createClass(ObjectStore, [{
		key: 'getDefaultStoreValue',
		value: function getDefaultStoreValue() {
			return {};
		}
	}, {
		key: 'applyGetValue',
		value: function applyGetValue() {
			var res = this.getDefaultStoreValue();
			this.eachChildren(function (child, key) {
				res[key] = child.value;
			});
			return res;
		}
	}, {
		key: 'applySetValue',
		value: function applySetValue(value) {
			this.eachChildren(function (child, key) {
				child.value = value[key];
			});
		}
	}, {
		key: 'applySetPristineValue',
		value: function applySetPristineValue() {
			var _this2 = this;

			this.isChecked = false;
			this.eachChildren(function (child, key) {
				var val = _this2.sourceValue[key];
				child.pristineValue = val;
			});
		}
	}, {
		key: 'applyGetErrorMessage',
		value: function applyGetErrorMessage() {
			var errorMessage = '';
			this.eachChildren(function (child) {
				if (!errorMessage) errorMessage = child.errorMessage;
			});
			return errorMessage;
		}
	}, {
		key: 'getFormData',
		value: function getFormData() {
			var res = this.getDefaultStoreValue();
			this.eachChildren(function (child, key) {
				var val = child.getFormData();
				if (!child.shouldIgnore(val)) res[key] = val;
			});
			var value = this.getOutputValue(res);
			return this.shouldIgnore(value) ? undefined : value;
		}
	}, {
		key: 'eachChildren',
		value: function eachChildren(iterator) {
			var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
			var _options$checked = options.checked,
			    checked = _options$checked === undefined ? true : _options$checked;
			var _iteratorNormalCompletion = true;
			var _didIteratorError = false;
			var _iteratorError = undefined;

			try {
				for (var _iterator = this.children[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
					var _step$value = _slicedToArray(_step.value, 2),
					    key = _step$value[0],
					    item = _step$value[1];

					if (!checked || item.isChecked) {
						iterator(item, key, this.children);
					}
				}
			} catch (err) {
				_didIteratorError = true;
				_iteratorError = err;
			} finally {
				try {
					if (!_iteratorNormalCompletion && _iterator.return) {
						_iterator.return();
					}
				} finally {
					if (_didIteratorError) {
						throw _iteratorError;
					}
				}
			}
		}
	}, {
		key: 'shouldCheck',
		value: function shouldCheck(key, value) {
			var val = this.sourceValue[key];
			var checked = val === value;
			if (checked) return checked;
			if (value === true) return val === 'true';
			return false;
		}
	}, {
		key: 'hasKey',
		value: function hasKey(key) {
			return this.sourceValue.hasOwnProperty(key);
		}
	}, {
		key: 'getChildren',
		value: function getChildren(key) {
			var children = this.children;

			if (children.has(key)) return children.get(key);
		}
	}, {
		key: 'setChildren',
		value: function setChildren(key, store) {
			this.children.set(key, store);
			return true;
		}
	}, {
		key: 'touch',
		value: function touch(isTouched) {
			this.eachChildren(function (child) {
				return child.touch(isTouched);
			});
		}
	}, {
		key: 'attach',
		value: function attach(key, options) {
			var sourceValue = this.sourceValue,
			    form = this.form;

			var val = sourceValue[key];
			return form.createChildren(this, key, val, options);
		}
	}, {
		key: 'detach',
		value: function detach(key) {
			this.children.delete(key);
		}
	}]);

	return ObjectStore;
}(PrimitiveStore), (_applyDecoratedDescriptor(_class.prototype, 'applySetValue', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'applySetValue'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'applySetPristineValue', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'applySetPristineValue'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'touch', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'touch'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'attach', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'attach'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'detach', [action], Object.getOwnPropertyDescriptor(_class.prototype, 'detach'), _class.prototype)), _class);
export { ObjectStore as default };
